"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class CheckList(Component):
    """
    A list of labels with options, the values aspect get all selected options.
    """
    _aspect_keys = []
    _children = []
    options = Aspect(required=True)
    values = Aspect(default=UNDEFINED)
    style = Aspect()
    class_name = Aspect()
    labels_class_name = Aspect()
    labels_style = Aspect()
    options_class_name = Aspect()
    options_style = Aspect()
    id = Aspect()

    def __init__(
            self,
            options: typing.List[typing.Dict[str, typing.Union[str, typing.Union[str, typing.Union[float, int]]]]],  # noqa: E501
            values: typing.Optional[typing.List[typing.Union[str, typing.Union[float, int]]]] = UNDEFINED,  # noqa: E501
            style: typing.Optional[typing.Dict] = UNDEFINED,
            class_name: typing.Optional[str] = UNDEFINED,
            labels_class_name: typing.Optional[str] = UNDEFINED,
            labels_style: typing.Optional[typing.Dict] = UNDEFINED,
            options_class_name: typing.Optional[str] = UNDEFINED,
            options_style: typing.Optional[typing.Dict] = UNDEFINED,
            id: typing.Optional[str] = UNDEFINED,
            identity: str = None
    ):
        """
        :param options: Items in the checklist with labels, values and
            elements attributes.
        :param values: Checked values (default=[])
        :param style: Style object of the container.
        :param class_name: Class name of the container.
        :param labels_class_name: Global class name to give to labels.
        :param labels_style: Global labels style objects.
        :param options_class_name: Global options class name.
        :param options_style: Global style object of options.
        :param id: Html id of the component, otherwise the identity is
            used.
        """
        Component.__init__(self, locals(), identity)
